<?php

return [
    'Names' => [
        'af' => 'अफ़्रीकी',
        'af_NA' => 'अफ़्रीकी (नामीबिया)',
        'af_ZA' => 'अफ़्रीकी (दक्षिण अफ़्रीका)',
        'ak' => 'अकन',
        'ak_GH' => 'अकन (घाना)',
        'am' => 'अम्हेरी',
        'am_ET' => 'अम्हेरी (इथियोपिया)',
        'ar' => 'अरबी',
        'ar_001' => 'अरबी (विश्व)',
        'ar_AE' => 'अरबी (संयुक्त अरब अमीरात)',
        'ar_BH' => 'अरबी (बहरीन)',
        'ar_DJ' => 'अरबी (जिबूती)',
        'ar_DZ' => 'अरबी (अल्जीरिया)',
        'ar_EG' => 'अरबी (मिस्र)',
        'ar_EH' => 'अरबी (पश्चिमी सहारा)',
        'ar_ER' => 'अरबी (इरिट्रिया)',
        'ar_IL' => 'अरबी (इज़राइल)',
        'ar_IQ' => 'अरबी (इराक)',
        'ar_JO' => 'अरबी (जॉर्डन)',
        'ar_KM' => 'अरबी (कोमोरोस)',
        'ar_KW' => 'अरबी (कुवैत)',
        'ar_LB' => 'अरबी (लेबनान)',
        'ar_LY' => 'अरबी (लीबिया)',
        'ar_MA' => 'अरबी (मोरक्को)',
        'ar_MR' => 'अरबी (मॉरिटानिया)',
        'ar_OM' => 'अरबी (ओमान)',
        'ar_PS' => 'अरबी (फ़िलिस्तीनी क्षेत्र)',
        'ar_QA' => 'अरबी (क़तर)',
        'ar_SA' => 'अरबी (सऊदी अरब)',
        'ar_SD' => 'अरबी (सूडान)',
        'ar_SO' => 'अरबी (सोमालिया)',
        'ar_SS' => 'अरबी (दक्षिण सूडान)',
        'ar_SY' => 'अरबी (सीरिया)',
        'ar_TD' => 'अरबी (चाड)',
        'ar_TN' => 'अरबी (ट्यूनीशिया)',
        'ar_YE' => 'अरबी (यमन)',
        'as' => 'असमिया',
        'as_IN' => 'असमिया (भारत)',
        'az' => 'अज़रबैजानी',
        'az_AZ' => 'अज़रबैजानी (अज़रबैजान)',
        'az_Cyrl' => 'अज़रबैजानी (सिरिलिक)',
        'az_Cyrl_AZ' => 'अज़रबैजानी (सिरिलिक, अज़रबैजान)',
        'az_Latn' => 'अज़रबैजानी (लैटिन)',
        'az_Latn_AZ' => 'अज़रबैजानी (लैटिन, अज़रबैजान)',
        'be' => 'बेलारूसी',
        'be_BY' => 'बेलारूसी (बेलारूस)',
        'bg' => 'बुल्गारियाई',
        'bg_BG' => 'बुल्गारियाई (बुल्गारिया)',
        'bm' => 'बाम्बारा',
        'bm_ML' => 'बाम्बारा (माली)',
        'bn' => 'बंगाली',
        'bn_BD' => 'बंगाली (बांग्लादेश)',
        'bn_IN' => 'बंगाली (भारत)',
        'bo' => 'तिब्बती',
        'bo_CN' => 'तिब्बती (चीन)',
        'bo_IN' => 'तिब्बती (भारत)',
        'br' => 'ब्रेटन',
        'br_FR' => 'ब्रेटन (फ़्रांस)',
        'bs' => 'बोस्नियाई',
        'bs_BA' => 'बोस्नियाई (बोस्निया और हर्ज़ेगोविना)',
        'bs_Cyrl' => 'बोस्नियाई (सिरिलिक)',
        'bs_Cyrl_BA' => 'बोस्नियाई (सिरिलिक, बोस्निया और हर्ज़ेगोविना)',
        'bs_Latn' => 'बोस्नियाई (लैटिन)',
        'bs_Latn_BA' => 'बोस्नियाई (लैटिन, बोस्निया और हर्ज़ेगोविना)',
        'ca' => 'कातालान',
        'ca_AD' => 'कातालान (एंडोरा)',
        'ca_ES' => 'कातालान (स्पेन)',
        'ca_FR' => 'कातालान (फ़्रांस)',
        'ca_IT' => 'कातालान (इटली)',
        'ce' => 'चेचन',
        'ce_RU' => 'चेचन (रूस)',
        'cs' => 'चेक',
        'cs_CZ' => 'चेक (चेकिया)',
        'cv' => 'चूवाश',
        'cv_RU' => 'चूवाश (रूस)',
        'cy' => 'वेल्श',
        'cy_GB' => 'वेल्श (यूनाइटेड किंगडम)',
        'da' => 'डेनिश',
        'da_DK' => 'डेनिश (डेनमार्क)',
        'da_GL' => 'डेनिश (ग्रीनलैंड)',
        'de' => 'जर्मन',
        'de_AT' => 'जर्मन (ऑस्ट्रिया)',
        'de_BE' => 'जर्मन (बेल्जियम)',
        'de_CH' => 'जर्मन (स्विट्ज़रलैंड)',
        'de_DE' => 'जर्मन (जर्मनी)',
        'de_IT' => 'जर्मन (इटली)',
        'de_LI' => 'जर्मन (लिचेंस्टीन)',
        'de_LU' => 'जर्मन (लग्ज़मबर्ग)',
        'dz' => 'ज़ोन्गखा',
        'dz_BT' => 'ज़ोन्गखा (भूटान)',
        'ee' => 'ईवे',
        'ee_GH' => 'ईवे (घाना)',
        'ee_TG' => 'ईवे (टोगो)',
        'el' => 'यूनानी',
        'el_CY' => 'यूनानी (साइप्रस)',
        'el_GR' => 'यूनानी (यूनान)',
        'en' => 'अंग्रेज़ी',
        'en_001' => 'अंग्रेज़ी (विश्व)',
        'en_150' => 'अंग्रेज़ी (यूरोप)',
        'en_AE' => 'अंग्रेज़ी (संयुक्त अरब अमीरात)',
        'en_AG' => 'अंग्रेज़ी (एंटिगुआ और बरबुडा)',
        'en_AI' => 'अंग्रेज़ी (एंग्विला)',
        'en_AS' => 'अंग्रेज़ी (अमेरिकी समोआ)',
        'en_AT' => 'अंग्रेज़ी (ऑस्ट्रिया)',
        'en_AU' => 'अंग्रेज़ी (ऑस्ट्रेलिया)',
        'en_BB' => 'अंग्रेज़ी (बारबाडोस)',
        'en_BE' => 'अंग्रेज़ी (बेल्जियम)',
        'en_BI' => 'अंग्रेज़ी (बुरुंडी)',
        'en_BM' => 'अंग्रेज़ी (बरमूडा)',
        'en_BS' => 'अंग्रेज़ी (बहामास)',
        'en_BW' => 'अंग्रेज़ी (बोत्स्वाना)',
        'en_BZ' => 'अंग्रेज़ी (बेलीज़)',
        'en_CA' => 'अंग्रेज़ी (कनाडा)',
        'en_CC' => 'अंग्रेज़ी (कोकोस [कीलिंग] द्वीपसमूह)',
        'en_CH' => 'अंग्रेज़ी (स्विट्ज़रलैंड)',
        'en_CK' => 'अंग्रेज़ी (कुक द्वीपसमूह)',
        'en_CM' => 'अंग्रेज़ी (कैमरून)',
        'en_CX' => 'अंग्रेज़ी (क्रिसमस द्वीप)',
        'en_CY' => 'अंग्रेज़ी (साइप्रस)',
        'en_DE' => 'अंग्रेज़ी (जर्मनी)',
        'en_DK' => 'अंग्रेज़ी (डेनमार्क)',
        'en_DM' => 'अंग्रेज़ी (डोमिनिका)',
        'en_ER' => 'अंग्रेज़ी (इरिट्रिया)',
        'en_FI' => 'अंग्रेज़ी (फ़िनलैंड)',
        'en_FJ' => 'अंग्रेज़ी (फ़िजी)',
        'en_FK' => 'अंग्रेज़ी (फ़ॉकलैंड द्वीपसमूह)',
        'en_FM' => 'अंग्रेज़ी (माइक्रोनेशिया)',
        'en_GB' => 'अंग्रेज़ी (यूनाइटेड किंगडम)',
        'en_GD' => 'अंग्रेज़ी (ग्रेनाडा)',
        'en_GG' => 'अंग्रेज़ी (गर्नसी)',
        'en_GH' => 'अंग्रेज़ी (घाना)',
        'en_GI' => 'अंग्रेज़ी (जिब्राल्टर)',
        'en_GM' => 'अंग्रेज़ी (गाम्बिया)',
        'en_GU' => 'अंग्रेज़ी (गुआम)',
        'en_GY' => 'अंग्रेज़ी (गुयाना)',
        'en_HK' => 'अंग्रेज़ी (हाँग काँग [चीन विशेष प्रशासनिक क्षेत्र])',
        'en_IE' => 'अंग्रेज़ी (आयरलैंड)',
        'en_IL' => 'अंग्रेज़ी (इज़राइल)',
        'en_IM' => 'अंग्रेज़ी (आइल ऑफ़ मैन)',
        'en_IN' => 'अंग्रेज़ी (भारत)',
        'en_IO' => 'अंग्रेज़ी (ब्रिटिश हिंद महासागरीय क्षेत्र)',
        'en_JE' => 'अंग्रेज़ी (जर्सी)',
        'en_JM' => 'अंग्रेज़ी (जमैका)',
        'en_KE' => 'अंग्रेज़ी (केन्या)',
        'en_KI' => 'अंग्रेज़ी (किरिबाती)',
        'en_KN' => 'अंग्रेज़ी (सेंट किट्स और नेविस)',
        'en_KY' => 'अंग्रेज़ी (कैमेन द्वीपसमूह)',
        'en_LC' => 'अंग्रेज़ी (सेंट लूसिया)',
        'en_LR' => 'अंग्रेज़ी (लाइबेरिया)',
        'en_LS' => 'अंग्रेज़ी (लेसोथो)',
        'en_MG' => 'अंग्रेज़ी (मेडागास्कर)',
        'en_MH' => 'अंग्रेज़ी (मार्शल द्वीपसमूह)',
        'en_MO' => 'अंग्रेज़ी (मकाऊ [विशेष प्रशासनिक क्षेत्र चीन])',
        'en_MP' => 'अंग्रेज़ी (उत्तरी मारियाना द्वीपसमूह)',
        'en_MS' => 'अंग्रेज़ी (मोंटसेरात)',
        'en_MT' => 'अंग्रेज़ी (माल्टा)',
        'en_MU' => 'अंग्रेज़ी (मॉरीशस)',
        'en_MV' => 'अंग्रेज़ी (मालदीव)',
        'en_MW' => 'अंग्रेज़ी (मलावी)',
        'en_MY' => 'अंग्रेज़ी (मलेशिया)',
        'en_NA' => 'अंग्रेज़ी (नामीबिया)',
        'en_NF' => 'अंग्रेज़ी (नॉरफ़ॉक द्वीप)',
        'en_NG' => 'अंग्रेज़ी (नाइजीरिया)',
        'en_NL' => 'अंग्रेज़ी (नीदरलैंड)',
        'en_NR' => 'अंग्रेज़ी (नाउरु)',
        'en_NU' => 'अंग्रेज़ी (नीयू)',
        'en_NZ' => 'अंग्रेज़ी (न्यूज़ीलैंड)',
        'en_PG' => 'अंग्रेज़ी (पापुआ न्यू गिनी)',
        'en_PH' => 'अंग्रेज़ी (फ़िलिपींस)',
        'en_PK' => 'अंग्रेज़ी (पाकिस्तान)',
        'en_PN' => 'अंग्रेज़ी (पिटकैर्न द्वीपसमूह)',
        'en_PR' => 'अंग्रेज़ी (पोर्टो रिको)',
        'en_PW' => 'अंग्रेज़ी (पलाऊ)',
        'en_RW' => 'अंग्रेज़ी (रवांडा)',
        'en_SB' => 'अंग्रेज़ी (सोलोमन द्वीपसमूह)',
        'en_SC' => 'अंग्रेज़ी (सेशेल्स)',
        'en_SD' => 'अंग्रेज़ी (सूडान)',
        'en_SE' => 'अंग्रेज़ी (स्वीडन)',
        'en_SG' => 'अंग्रेज़ी (सिंगापुर)',
        'en_SH' => 'अंग्रेज़ी (सेंट हेलेना)',
        'en_SI' => 'अंग्रेज़ी (स्लोवेनिया)',
        'en_SL' => 'अंग्रेज़ी (सिएरा लियोन)',
        'en_SS' => 'अंग्रेज़ी (दक्षिण सूडान)',
        'en_SX' => 'अंग्रेज़ी (सिंट मार्टिन)',
        'en_SZ' => 'अंग्रेज़ी (एस्वाटिनी)',
        'en_TC' => 'अंग्रेज़ी (तुर्क और कैकोज़ द्वीपसमूह)',
        'en_TK' => 'अंग्रेज़ी (तोकेलाउ)',
        'en_TO' => 'अंग्रेज़ी (टोंगा)',
        'en_TT' => 'अंग्रेज़ी (त्रिनिदाद और टोबैगो)',
        'en_TV' => 'अंग्रेज़ी (तुवालू)',
        'en_TZ' => 'अंग्रेज़ी (तंज़ानिया)',
        'en_UG' => 'अंग्रेज़ी (युगांडा)',
        'en_UM' => 'अंग्रेज़ी (यू॰एस॰ आउटलाइंग द्वीपसमूह)',
        'en_US' => 'अंग्रेज़ी (संयुक्त राज्य)',
        'en_VC' => 'अंग्रेज़ी (सेंट विंसेंट और ग्रेनाडाइंस)',
        'en_VG' => 'अंग्रेज़ी (ब्रिटिश वर्जिन द्वीपसमूह)',
        'en_VI' => 'अंग्रेज़ी (यू॰एस॰ वर्जिन द्वीपसमूह)',
        'en_VU' => 'अंग्रेज़ी (वनुआतू)',
        'en_WS' => 'अंग्रेज़ी (समोआ)',
        'en_ZA' => 'अंग्रेज़ी (दक्षिण अफ़्रीका)',
        'en_ZM' => 'अंग्रेज़ी (ज़ाम्बिया)',
        'en_ZW' => 'अंग्रेज़ी (ज़िम्बाब्वे)',
        'eo' => 'एस्पेरेंतो',
        'eo_001' => 'एस्पेरेंतो (विश्व)',
        'es' => 'स्पेनिश',
        'es_419' => 'स्पेनिश (लैटिन अमेरिका)',
        'es_AR' => 'स्पेनिश (अर्जेंटीना)',
        'es_BO' => 'स्पेनिश (बोलीविया)',
        'es_BR' => 'स्पेनिश (ब्राज़ील)',
        'es_BZ' => 'स्पेनिश (बेलीज़)',
        'es_CL' => 'स्पेनिश (चिली)',
        'es_CO' => 'स्पेनिश (कोलंबिया)',
        'es_CR' => 'स्पेनिश (कोस्टारिका)',
        'es_CU' => 'स्पेनिश (क्यूबा)',
        'es_DO' => 'स्पेनिश (डोमिनिकन गणराज्य)',
        'es_EC' => 'स्पेनिश (इक्वाडोर)',
        'es_ES' => 'स्पेनिश (स्पेन)',
        'es_GQ' => 'स्पेनिश (इक्वेटोरियल गिनी)',
        'es_GT' => 'स्पेनिश (ग्वाटेमाला)',
        'es_HN' => 'स्पेनिश (होंडूरास)',
        'es_MX' => 'स्पेनिश (मैक्सिको)',
        'es_NI' => 'स्पेनिश (निकारागुआ)',
        'es_PA' => 'स्पेनिश (पनामा)',
        'es_PE' => 'स्पेनिश (पेरू)',
        'es_PH' => 'स्पेनिश (फ़िलिपींस)',
        'es_PR' => 'स्पेनिश (पोर्टो रिको)',
        'es_PY' => 'स्पेनिश (पराग्वे)',
        'es_SV' => 'स्पेनिश (अल सल्वाडोर)',
        'es_US' => 'स्पेनिश (संयुक्त राज्य)',
        'es_UY' => 'स्पेनिश (उरूग्वे)',
        'es_VE' => 'स्पेनिश (वेनेज़ुएला)',
        'et' => 'एस्टोनियाई',
        'et_EE' => 'एस्टोनियाई (एस्टोनिया)',
        'eu' => 'बास्क',
        'eu_ES' => 'बास्क (स्पेन)',
        'fa' => 'फ़ारसी',
        'fa_AF' => 'फ़ारसी (अफ़गानिस्तान)',
        'fa_IR' => 'फ़ारसी (ईरान)',
        'ff' => 'फुलाह',
        'ff_Adlm' => 'फुलाह (ऐडलम)',
        'ff_Adlm_BF' => 'फुलाह (ऐडलम, बुर्किना फ़ासो)',
        'ff_Adlm_CM' => 'फुलाह (ऐडलम, कैमरून)',
        'ff_Adlm_GH' => 'फुलाह (ऐडलम, घाना)',
        'ff_Adlm_GM' => 'फुलाह (ऐडलम, गाम्बिया)',
        'ff_Adlm_GN' => 'फुलाह (ऐडलम, गिनी)',
        'ff_Adlm_GW' => 'फुलाह (ऐडलम, गिनी-बिसाउ)',
        'ff_Adlm_LR' => 'फुलाह (ऐडलम, लाइबेरिया)',
        'ff_Adlm_MR' => 'फुलाह (ऐडलम, मॉरिटानिया)',
        'ff_Adlm_NE' => 'फुलाह (ऐडलम, नाइजर)',
        'ff_Adlm_NG' => 'फुलाह (ऐडलम, नाइजीरिया)',
        'ff_Adlm_SL' => 'फुलाह (ऐडलम, सिएरा लियोन)',
        'ff_Adlm_SN' => 'फुलाह (ऐडलम, सेनेगल)',
        'ff_CM' => 'फुलाह (कैमरून)',
        'ff_GN' => 'फुलाह (गिनी)',
        'ff_Latn' => 'फुलाह (लैटिन)',
        'ff_Latn_BF' => 'फुलाह (लैटिन, बुर्किना फ़ासो)',
        'ff_Latn_CM' => 'फुलाह (लैटिन, कैमरून)',
        'ff_Latn_GH' => 'फुलाह (लैटिन, घाना)',
        'ff_Latn_GM' => 'फुलाह (लैटिन, गाम्बिया)',
        'ff_Latn_GN' => 'फुलाह (लैटिन, गिनी)',
        'ff_Latn_GW' => 'फुलाह (लैटिन, गिनी-बिसाउ)',
        'ff_Latn_LR' => 'फुलाह (लैटिन, लाइबेरिया)',
        'ff_Latn_MR' => 'फुलाह (लैटिन, मॉरिटानिया)',
        'ff_Latn_NE' => 'फुलाह (लैटिन, नाइजर)',
        'ff_Latn_NG' => 'फुलाह (लैटिन, नाइजीरिया)',
        'ff_Latn_SL' => 'फुलाह (लैटिन, सिएरा लियोन)',
        'ff_Latn_SN' => 'फुलाह (लैटिन, सेनेगल)',
        'ff_MR' => 'फुलाह (मॉरिटानिया)',
        'ff_SN' => 'फुलाह (सेनेगल)',
        'fi' => 'फ़िनिश',
        'fi_FI' => 'फ़िनिश (फ़िनलैंड)',
        'fo' => 'फ़ैरोइज़',
        'fo_DK' => 'फ़ैरोइज़ (डेनमार्क)',
        'fo_FO' => 'फ़ैरोइज़ (फ़ेरो द्वीपसमूह)',
        'fr' => 'फ़्रेंच',
        'fr_BE' => 'फ़्रेंच (बेल्जियम)',
        'fr_BF' => 'फ़्रेंच (बुर्किना फ़ासो)',
        'fr_BI' => 'फ़्रेंच (बुरुंडी)',
        'fr_BJ' => 'फ़्रेंच (बेनिन)',
        'fr_BL' => 'फ़्रेंच (सेंट बार्थेलेमी)',
        'fr_CA' => 'फ़्रेंच (कनाडा)',
        'fr_CD' => 'फ़्रेंच (कांगो - किंशासा)',
        'fr_CF' => 'फ़्रेंच (मध्य अफ़्रीकी गणराज्य)',
        'fr_CG' => 'फ़्रेंच (कांगो – ब्राज़ाविल)',
        'fr_CH' => 'फ़्रेंच (स्विट्ज़रलैंड)',
        'fr_CI' => 'फ़्रेंच (कोत दिवुआर)',
        'fr_CM' => 'फ़्रेंच (कैमरून)',
        'fr_DJ' => 'फ़्रेंच (जिबूती)',
        'fr_DZ' => 'फ़्रेंच (अल्जीरिया)',
        'fr_FR' => 'फ़्रेंच (फ़्रांस)',
        'fr_GA' => 'फ़्रेंच (गैबॉन)',
        'fr_GF' => 'फ़्रेंच (फ़्रेंच गुयाना)',
        'fr_GN' => 'फ़्रेंच (गिनी)',
        'fr_GP' => 'फ़्रेंच (ग्वाडेलूप)',
        'fr_GQ' => 'फ़्रेंच (इक्वेटोरियल गिनी)',
        'fr_HT' => 'फ़्रेंच (हैती)',
        'fr_KM' => 'फ़्रेंच (कोमोरोस)',
        'fr_LU' => 'फ़्रेंच (लग्ज़मबर्ग)',
        'fr_MA' => 'फ़्रेंच (मोरक्को)',
        'fr_MC' => 'फ़्रेंच (मोनाको)',
        'fr_MF' => 'फ़्रेंच (सेंट मार्टिन)',
        'fr_MG' => 'फ़्रेंच (मेडागास्कर)',
        'fr_ML' => 'फ़्रेंच (माली)',
        'fr_MQ' => 'फ़्रेंच (मार्टीनिक)',
        'fr_MR' => 'फ़्रेंच (मॉरिटानिया)',
        'fr_MU' => 'फ़्रेंच (मॉरीशस)',
        'fr_NC' => 'फ़्रेंच (न्यू कैलेडोनिया)',
        'fr_NE' => 'फ़्रेंच (नाइजर)',
        'fr_PF' => 'फ़्रेंच (फ़्रेंच पोलिनेशिया)',
        'fr_PM' => 'फ़्रेंच (सेंट पिएरे और मिक्वेलान)',
        'fr_RE' => 'फ़्रेंच (रियूनियन)',
        'fr_RW' => 'फ़्रेंच (रवांडा)',
        'fr_SC' => 'फ़्रेंच (सेशेल्स)',
        'fr_SN' => 'फ़्रेंच (सेनेगल)',
        'fr_SY' => 'फ़्रेंच (सीरिया)',
        'fr_TD' => 'फ़्रेंच (चाड)',
        'fr_TG' => 'फ़्रेंच (टोगो)',
        'fr_TN' => 'फ़्रेंच (ट्यूनीशिया)',
        'fr_VU' => 'फ़्रेंच (वनुआतू)',
        'fr_WF' => 'फ़्रेंच (वालिस और फ़्यूचूना)',
        'fr_YT' => 'फ़्रेंच (मायोते)',
        'fy' => 'पश्चिमी फ़्रिसियाई',
        'fy_NL' => 'पश्चिमी फ़्रिसियाई (नीदरलैंड)',
        'ga' => 'आयरिश',
        'ga_GB' => 'आयरिश (यूनाइटेड किंगडम)',
        'ga_IE' => 'आयरिश (आयरलैंड)',
        'gd' => 'स्कॉटिश गाएलिक',
        'gd_GB' => 'स्कॉटिश गाएलिक (यूनाइटेड किंगडम)',
        'gl' => 'गैलिशियन',
        'gl_ES' => 'गैलिशियन (स्पेन)',
        'gu' => 'गुजराती',
        'gu_IN' => 'गुजराती (भारत)',
        'gv' => 'मैंक्स',
        'gv_IM' => 'मैंक्स (आइल ऑफ़ मैन)',
        'ha' => 'हौसा',
        'ha_GH' => 'हौसा (घाना)',
        'ha_NE' => 'हौसा (नाइजर)',
        'ha_NG' => 'हौसा (नाइजीरिया)',
        'he' => 'हिब्रू',
        'he_IL' => 'हिब्रू (इज़राइल)',
        'hi' => 'हिन्दी',
        'hi_IN' => 'हिन्दी (भारत)',
        'hi_Latn' => 'हिन्दी (लैटिन)',
        'hi_Latn_IN' => 'हिन्दी (लैटिन, भारत)',
        'hr' => 'क्रोएशियाई',
        'hr_BA' => 'क्रोएशियाई (बोस्निया और हर्ज़ेगोविना)',
        'hr_HR' => 'क्रोएशियाई (क्रोएशिया)',
        'hu' => 'हंगेरियाई',
        'hu_HU' => 'हंगेरियाई (हंगरी)',
        'hy' => 'आर्मेनियाई',
        'hy_AM' => 'आर्मेनियाई (आर्मेनिया)',
        'ia' => 'इंटरलिंगुआ',
        'ia_001' => 'इंटरलिंगुआ (विश्व)',
        'id' => 'इंडोनेशियाई',
        'id_ID' => 'इंडोनेशियाई (इंडोनेशिया)',
        'ig' => 'ईग्बो',
        'ig_NG' => 'ईग्बो (नाइजीरिया)',
        'ii' => 'सिचुआन यी',
        'ii_CN' => 'सिचुआन यी (चीन)',
        'is' => 'आइसलैंडिक',
        'is_IS' => 'आइसलैंडिक (आइसलैंड)',
        'it' => 'इतालवी',
        'it_CH' => 'इतालवी (स्विट्ज़रलैंड)',
        'it_IT' => 'इतालवी (इटली)',
        'it_SM' => 'इतालवी (सैन मेरीनो)',
        'it_VA' => 'इतालवी (वेटिकन सिटी)',
        'ja' => 'जापानी',
        'ja_JP' => 'जापानी (जापान)',
        'jv' => 'जावानीज़',
        'jv_ID' => 'जावानीज़ (इंडोनेशिया)',
        'ka' => 'जॉर्जियाई',
        'ka_GE' => 'जॉर्जियाई (जॉर्जिया)',
        'ki' => 'किकुयू',
        'ki_KE' => 'किकुयू (केन्या)',
        'kk' => 'कज़ाख़',
        'kk_KZ' => 'कज़ाख़ (कज़ाखस्तान)',
        'kl' => 'कलालीसुत',
        'kl_GL' => 'कलालीसुत (ग्रीनलैंड)',
        'km' => 'खमेर',
        'km_KH' => 'खमेर (कंबोडिया)',
        'kn' => 'कन्नड़',
        'kn_IN' => 'कन्नड़ (भारत)',
        'ko' => 'कोरियाई',
        'ko_KP' => 'कोरियाई (उत्तर कोरिया)',
        'ko_KR' => 'कोरियाई (दक्षिण कोरिया)',
        'ks' => 'कश्मीरी',
        'ks_Arab' => 'कश्मीरी (अरबी)',
        'ks_Arab_IN' => 'कश्मीरी (अरबी, भारत)',
        'ks_Deva' => 'कश्मीरी (देवनागरी)',
        'ks_Deva_IN' => 'कश्मीरी (देवनागरी, भारत)',
        'ks_IN' => 'कश्मीरी (भारत)',
        'ku' => 'कुर्दिश',
        'ku_TR' => 'कुर्दिश (तुर्किये)',
        'kw' => 'कोर्निश',
        'kw_GB' => 'कोर्निश (यूनाइटेड किंगडम)',
        'ky' => 'किर्गीज़',
        'ky_KG' => 'किर्गीज़ (किर्गिज़स्तान)',
        'lb' => 'लग्ज़मबर्गी',
        'lb_LU' => 'लग्ज़मबर्गी (लग्ज़मबर्ग)',
        'lg' => 'गांडा',
        'lg_UG' => 'गांडा (युगांडा)',
        'ln' => 'लिंगाला',
        'ln_AO' => 'लिंगाला (अंगोला)',
        'ln_CD' => 'लिंगाला (कांगो - किंशासा)',
        'ln_CF' => 'लिंगाला (मध्य अफ़्रीकी गणराज्य)',
        'ln_CG' => 'लिंगाला (कांगो – ब्राज़ाविल)',
        'lo' => 'लाओ',
        'lo_LA' => 'लाओ (लाओस)',
        'lt' => 'लिथुआनियाई',
        'lt_LT' => 'लिथुआनियाई (लिथुआनिया)',
        'lu' => 'ल्यूबा-कटांगा',
        'lu_CD' => 'ल्यूबा-कटांगा (कांगो - किंशासा)',
        'lv' => 'लातवियाई',
        'lv_LV' => 'लातवियाई (लातविया)',
        'mg' => 'मालागासी',
        'mg_MG' => 'मालागासी (मेडागास्कर)',
        'mi' => 'माओरी',
        'mi_NZ' => 'माओरी (न्यूज़ीलैंड)',
        'mk' => 'मकदूनियाई',
        'mk_MK' => 'मकदूनियाई (उत्तरी मकदूनिया)',
        'ml' => 'मलयालम',
        'ml_IN' => 'मलयालम (भारत)',
        'mn' => 'मंगोलियाई',
        'mn_MN' => 'मंगोलियाई (मंगोलिया)',
        'mr' => 'मराठी',
        'mr_IN' => 'मराठी (भारत)',
        'ms' => 'मलय',
        'ms_BN' => 'मलय (ब्रूनेई)',
        'ms_ID' => 'मलय (इंडोनेशिया)',
        'ms_MY' => 'मलय (मलेशिया)',
        'ms_SG' => 'मलय (सिंगापुर)',
        'mt' => 'माल्टीज़',
        'mt_MT' => 'माल्टीज़ (माल्टा)',
        'my' => 'बर्मीज़',
        'my_MM' => 'बर्मीज़ (म्यांमार [बर्मा])',
        'nb' => 'नॉर्वेजियाई बोकमाल',
        'nb_NO' => 'नॉर्वेजियाई बोकमाल (नॉर्वे)',
        'nb_SJ' => 'नॉर्वेजियाई बोकमाल (स्वालबार्ड और जान मायेन)',
        'nd' => 'उत्तरी देबेल',
        'nd_ZW' => 'उत्तरी देबेल (ज़िम्बाब्वे)',
        'ne' => 'नेपाली',
        'ne_IN' => 'नेपाली (भारत)',
        'ne_NP' => 'नेपाली (नेपाल)',
        'nl' => 'डच',
        'nl_AW' => 'डच (अरूबा)',
        'nl_BE' => 'डच (बेल्जियम)',
        'nl_BQ' => 'डच (कैरिबियन नीदरलैंड)',
        'nl_CW' => 'डच (कुरासाओ)',
        'nl_NL' => 'डच (नीदरलैंड)',
        'nl_SR' => 'डच (सूरीनाम)',
        'nl_SX' => 'डच (सिंट मार्टिन)',
        'nn' => 'नॉर्वेजियाई नॉयनॉर्स्क',
        'nn_NO' => 'नॉर्वेजियाई नॉयनॉर्स्क (नॉर्वे)',
        'no' => 'नॉर्वेजियाई',
        'no_NO' => 'नॉर्वेजियाई (नॉर्वे)',
        'om' => 'ओरोमो',
        'om_ET' => 'ओरोमो (इथियोपिया)',
        'om_KE' => 'ओरोमो (केन्या)',
        'or' => 'ओड़िया',
        'or_IN' => 'ओड़िया (भारत)',
        'os' => 'ओस्सेटिक',
        'os_GE' => 'ओस्सेटिक (जॉर्जिया)',
        'os_RU' => 'ओस्सेटिक (रूस)',
        'pa' => 'पंजाबी',
        'pa_Arab' => 'पंजाबी (अरबी)',
        'pa_Arab_PK' => 'पंजाबी (अरबी, पाकिस्तान)',
        'pa_Guru' => 'पंजाबी (गुरमुखी)',
        'pa_Guru_IN' => 'पंजाबी (गुरमुखी, भारत)',
        'pa_IN' => 'पंजाबी (भारत)',
        'pa_PK' => 'पंजाबी (पाकिस्तान)',
        'pl' => 'पोलिश',
        'pl_PL' => 'पोलिश (पोलैंड)',
        'ps' => 'पश्तो',
        'ps_AF' => 'पश्तो (अफ़गानिस्तान)',
        'ps_PK' => 'पश्तो (पाकिस्तान)',
        'pt' => 'पुर्तगाली',
        'pt_AO' => 'पुर्तगाली (अंगोला)',
        'pt_BR' => 'पुर्तगाली (ब्राज़ील)',
        'pt_CH' => 'पुर्तगाली (स्विट्ज़रलैंड)',
        'pt_CV' => 'पुर्तगाली (केप वर्ड)',
        'pt_GQ' => 'पुर्तगाली (इक्वेटोरियल गिनी)',
        'pt_GW' => 'पुर्तगाली (गिनी-बिसाउ)',
        'pt_LU' => 'पुर्तगाली (लग्ज़मबर्ग)',
        'pt_MO' => 'पुर्तगाली (मकाऊ [विशेष प्रशासनिक क्षेत्र चीन])',
        'pt_MZ' => 'पुर्तगाली (मोज़ांबिक)',
        'pt_PT' => 'पुर्तगाली (पुर्तगाल)',
        'pt_ST' => 'पुर्तगाली (साओ टोम और प्रिंसिपे)',
        'pt_TL' => 'पुर्तगाली (तिमोर-लेस्त)',
        'qu' => 'क्वेचुआ',
        'qu_BO' => 'क्वेचुआ (बोलीविया)',
        'qu_EC' => 'क्वेचुआ (इक्वाडोर)',
        'qu_PE' => 'क्वेचुआ (पेरू)',
        'rm' => 'रोमान्श',
        'rm_CH' => 'रोमान्श (स्विट्ज़रलैंड)',
        'rn' => 'रुन्दी',
        'rn_BI' => 'रुन्दी (बुरुंडी)',
        'ro' => 'रोमानियाई',
        'ro_MD' => 'रोमानियाई (मॉल्डोवा)',
        'ro_RO' => 'रोमानियाई (रोमानिया)',
        'ru' => 'रूसी',
        'ru_BY' => 'रूसी (बेलारूस)',
        'ru_KG' => 'रूसी (किर्गिज़स्तान)',
        'ru_KZ' => 'रूसी (कज़ाखस्तान)',
        'ru_MD' => 'रूसी (मॉल्डोवा)',
        'ru_RU' => 'रूसी (रूस)',
        'ru_UA' => 'रूसी (यूक्रेन)',
        'rw' => 'किन्यारवांडा',
        'rw_RW' => 'किन्यारवांडा (रवांडा)',
        'sa' => 'संस्कृत',
        'sa_IN' => 'संस्कृत (भारत)',
        'sc' => 'सार्दिनियन',
        'sc_IT' => 'सार्दिनियन (इटली)',
        'sd' => 'सिंधी',
        'sd_Arab' => 'सिंधी (अरबी)',
        'sd_Arab_PK' => 'सिंधी (अरबी, पाकिस्तान)',
        'sd_Deva' => 'सिंधी (देवनागरी)',
        'sd_Deva_IN' => 'सिंधी (देवनागरी, भारत)',
        'sd_IN' => 'सिंधी (भारत)',
        'sd_PK' => 'सिंधी (पाकिस्तान)',
        'se' => 'नॉर्दन सामी',
        'se_FI' => 'नॉर्दन सामी (फ़िनलैंड)',
        'se_NO' => 'नॉर्दन सामी (नॉर्वे)',
        'se_SE' => 'नॉर्दन सामी (स्वीडन)',
        'sg' => 'सांगो',
        'sg_CF' => 'सांगो (मध्य अफ़्रीकी गणराज्य)',
        'sh' => 'सेर्बो-क्रोएशियाई',
        'sh_BA' => 'सेर्बो-क्रोएशियाई (बोस्निया और हर्ज़ेगोविना)',
        'si' => 'सिंहली',
        'si_LK' => 'सिंहली (श्रीलंका)',
        'sk' => 'स्लोवाक',
        'sk_SK' => 'स्लोवाक (स्लोवाकिया)',
        'sl' => 'स्लोवेनियाई',
        'sl_SI' => 'स्लोवेनियाई (स्लोवेनिया)',
        'sn' => 'शोणा',
        'sn_ZW' => 'शोणा (ज़िम्बाब्वे)',
        'so' => 'सोमाली',
        'so_DJ' => 'सोमाली (जिबूती)',
        'so_ET' => 'सोमाली (इथियोपिया)',
        'so_KE' => 'सोमाली (केन्या)',
        'so_SO' => 'सोमाली (सोमालिया)',
        'sq' => 'अल्बानियाई',
        'sq_AL' => 'अल्बानियाई (अल्बानिया)',
        'sq_MK' => 'अल्बानियाई (उत्तरी मकदूनिया)',
        'sr' => 'सर्बियाई',
        'sr_BA' => 'सर्बियाई (बोस्निया और हर्ज़ेगोविना)',
        'sr_Cyrl' => 'सर्बियाई (सिरिलिक)',
        'sr_Cyrl_BA' => 'सर्बियाई (सिरिलिक, बोस्निया और हर्ज़ेगोविना)',
        'sr_Cyrl_ME' => 'सर्बियाई (सिरिलिक, मोंटेनेग्रो)',
        'sr_Cyrl_RS' => 'सर्बियाई (सिरिलिक, सर्बिया)',
        'sr_Latn' => 'सर्बियाई (लैटिन)',
        'sr_Latn_BA' => 'सर्बियाई (लैटिन, बोस्निया और हर्ज़ेगोविना)',
        'sr_Latn_ME' => 'सर्बियाई (लैटिन, मोंटेनेग्रो)',
        'sr_Latn_RS' => 'सर्बियाई (लैटिन, सर्बिया)',
        'sr_ME' => 'सर्बियाई (मोंटेनेग्रो)',
        'sr_RS' => 'सर्बियाई (सर्बिया)',
        'su' => 'सुंडानी',
        'su_ID' => 'सुंडानी (इंडोनेशिया)',
        'su_Latn' => 'सुंडानी (लैटिन)',
        'su_Latn_ID' => 'सुंडानी (लैटिन, इंडोनेशिया)',
        'sv' => 'स्वीडिश',
        'sv_AX' => 'स्वीडिश (एलैंड द्वीपसमूह)',
        'sv_FI' => 'स्वीडिश (फ़िनलैंड)',
        'sv_SE' => 'स्वीडिश (स्वीडन)',
        'sw' => 'स्वाहिली',
        'sw_CD' => 'स्वाहिली (कांगो - किंशासा)',
        'sw_KE' => 'स्वाहिली (केन्या)',
        'sw_TZ' => 'स्वाहिली (तंज़ानिया)',
        'sw_UG' => 'स्वाहिली (युगांडा)',
        'ta' => 'तमिल',
        'ta_IN' => 'तमिल (भारत)',
        'ta_LK' => 'तमिल (श्रीलंका)',
        'ta_MY' => 'तमिल (मलेशिया)',
        'ta_SG' => 'तमिल (सिंगापुर)',
        'te' => 'तेलुगू',
        'te_IN' => 'तेलुगू (भारत)',
        'tg' => 'ताजिक',
        'tg_TJ' => 'ताजिक (ताजिकिस्तान)',
        'th' => 'थाई',
        'th_TH' => 'थाई (थाईलैंड)',
        'ti' => 'तिग्रीन्या',
        'ti_ER' => 'तिग्रीन्या (इरिट्रिया)',
        'ti_ET' => 'तिग्रीन्या (इथियोपिया)',
        'tk' => 'तुर्कमेन',
        'tk_TM' => 'तुर्कमेन (तुर्कमेनिस्तान)',
        'tl' => 'टैगलॉग',
        'tl_PH' => 'टैगलॉग (फ़िलिपींस)',
        'to' => 'टोंगन',
        'to_TO' => 'टोंगन (टोंगा)',
        'tr' => 'तुर्की',
        'tr_CY' => 'तुर्की (साइप्रस)',
        'tr_TR' => 'तुर्की (तुर्किये)',
        'tt' => 'तातार',
        'tt_RU' => 'तातार (रूस)',
        'ug' => 'उइगर',
        'ug_CN' => 'उइगर (चीन)',
        'uk' => 'यूक्रेनियाई',
        'uk_UA' => 'यूक्रेनियाई (यूक्रेन)',
        'ur' => 'उर्दू',
        'ur_IN' => 'उर्दू (भारत)',
        'ur_PK' => 'उर्दू (पाकिस्तान)',
        'uz' => 'उज़्बेक',
        'uz_AF' => 'उज़्बेक (अफ़गानिस्तान)',
        'uz_Arab' => 'उज़्बेक (अरबी)',
        'uz_Arab_AF' => 'उज़्बेक (अरबी, अफ़गानिस्तान)',
        'uz_Cyrl' => 'उज़्बेक (सिरिलिक)',
        'uz_Cyrl_UZ' => 'उज़्बेक (सिरिलिक, उज़्बेकिस्तान)',
        'uz_Latn' => 'उज़्बेक (लैटिन)',
        'uz_Latn_UZ' => 'उज़्बेक (लैटिन, उज़्बेकिस्तान)',
        'uz_UZ' => 'उज़्बेक (उज़्बेकिस्तान)',
        'vi' => 'वियतनामी',
        'vi_VN' => 'वियतनामी (वियतनाम)',
        'wo' => 'वोलोफ़',
        'wo_SN' => 'वोलोफ़ (सेनेगल)',
        'xh' => 'ख़ोसा',
        'xh_ZA' => 'ख़ोसा (दक्षिण अफ़्रीका)',
        'yi' => 'यहूदी',
        'yi_001' => 'यहूदी (विश्व)',
        'yo' => 'योरूबा',
        'yo_BJ' => 'योरूबा (बेनिन)',
        'yo_NG' => 'योरूबा (नाइजीरिया)',
        'zh' => 'चीनी',
        'zh_CN' => 'चीनी (चीन)',
        'zh_HK' => 'चीनी (हाँग काँग [चीन विशेष प्रशासनिक क्षेत्र])',
        'zh_Hans' => 'चीनी (सरलीकृत)',
        'zh_Hans_CN' => 'चीनी (सरलीकृत, चीन)',
        'zh_Hans_HK' => 'चीनी (सरलीकृत, हाँग काँग [चीन विशेष प्रशासनिक क्षेत्र])',
        'zh_Hans_MO' => 'चीनी (सरलीकृत, मकाऊ [विशेष प्रशासनिक क्षेत्र चीन])',
        'zh_Hans_SG' => 'चीनी (सरलीकृत, सिंगापुर)',
        'zh_Hant' => 'चीनी (पारंपरिक)',
        'zh_Hant_HK' => 'चीनी (पारंपरिक, हाँग काँग [चीन विशेष प्रशासनिक क्षेत्र])',
        'zh_Hant_MO' => 'चीनी (पारंपरिक, मकाऊ [विशेष प्रशासनिक क्षेत्र चीन])',
        'zh_Hant_TW' => 'चीनी (पारंपरिक, ताइवान)',
        'zh_MO' => 'चीनी (मकाऊ [विशेष प्रशासनिक क्षेत्र चीन])',
        'zh_SG' => 'चीनी (सिंगापुर)',
        'zh_TW' => 'चीनी (ताइवान)',
        'zu' => 'ज़ुलू',
        'zu_ZA' => 'ज़ुलू (दक्षिण अफ़्रीका)',
    ],
];
